@@ -1457,7 +1457,13 @@ int qc_fmt_convert(struct quickcam *qc, unsigned char *src, unsigned int src_len
 			case 5:
 				qc_imag_bay2rgb_gptm(bayerwin, qc->sensor_data.width,
 						dst, 3*qc->vwin.width, 
-						qc->vwin.width, qc->vwin.height, 3, qc->vpic.whiteness);
+						qc->vwin.width, qc->vwin.height, 3,
+#ifdef WHITENESS_IS_SHUTTER
+						     32768
+#else
+						     qc->vpic.whiteness
+#endif
+						     );
 				break;
 			}
 			goto rgb24;
