@@ -109,6 +109,12 @@ struct qc_userlut {
 #include <asm/pgtable.h>		/* This is required for testing pte_offset_map */
 #include <linux/spinlock.h>
 
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,0)
+#ifdef USE_KREF
+#include <linux/kref.h>
+#endif
+#endif
+
 /* {{{ [fold] SECTION: user configuration */
 #define VERSION		"QuickCam Messenger/Communicate USB $Date: 2004/12/21 10:00:00 $"
 #ifndef COMPRESS
@@ -540,11 +546,12 @@ struct quickcam {
 	int users;				/* User count (simultaneous open count) */
 	struct usb_device *dev;			/* USB device, set to NULL when camera disconnected and interrupts disabled */
 
+	int bEndpointAddress;
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,0)
-  //struct usb_interface *interface;
+#ifdef USE_KREF
+	struct kref			kref;
+#endif
 #endif
-  //struct usb_interface_descriptor *ifacedesc;
-  int bEndpointAddress;
 
 	unsigned char iface;			/* The interface number in the camera device we are bound to */
 	Bool connected;				/* Set to FALSE immediately when the camera is disconnected (even before interrupts are disabled) */
